#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

namespace NinjaTrader.Indicator
{
	[Description("Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).")]
	[Gui.Design.DisplayName("VOLBasedColor (Volume)")]
	public class VOLBasedColor : Indicator
	{
		protected override void Initialize()
		{
			Add(new Plot(new Pen(Color.Red, 2), PlotStyle.Bar, "Volume Down"));
			Add(new Plot(new Pen(Color.LightGreen, 2), PlotStyle.Bar, "Volume Up"));
			Add(new Line(Color.DarkGray, 0, "Zero line"));
		}

		protected override void OnBarUpdate()
		{
			if (CurrentBar < 1)
				return;
			if(VOL()[0] < VOL()[1])
				VOLDown.Set(Volume[0]);
			else
				VOLUp.Set(Volume[0]);
		}
		
		#region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries VOLDown
        {
            get { return Values[0]; }
        }

		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries VOLUp
        {
            get { return Values[1]; }
        }
        #endregion
	}
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private VOLBasedColor[] cacheVOLBasedColor = null;

        private static VOLBasedColor checkVOLBasedColor = new VOLBasedColor();

        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        public VOLBasedColor VOLBasedColor()
        {
            return VOLBasedColor(Input);
        }

        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        public VOLBasedColor VOLBasedColor(Data.IDataSeries input)
        {

            if (cacheVOLBasedColor != null)
                for (int idx = 0; idx < cacheVOLBasedColor.Length; idx++)
                    if (cacheVOLBasedColor[idx].EqualsInput(input))
                        return cacheVOLBasedColor[idx];

            VOLBasedColor indicator = new VOLBasedColor();
            indicator.SetUp();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;

            VOLBasedColor[] tmp = new VOLBasedColor[cacheVOLBasedColor == null ? 1 : cacheVOLBasedColor.Length + 1];
            if (cacheVOLBasedColor != null)
                cacheVOLBasedColor.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheVOLBasedColor = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.VOLBasedColor VOLBasedColor()
        {
            return _indicator.VOLBasedColor(Input);
        }

        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        public Indicator.VOLBasedColor VOLBasedColor(Data.IDataSeries input)
        {
            return _indicator.VOLBasedColor(input);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.VOLBasedColor VOLBasedColor()
        {
            return _indicator.VOLBasedColor(Input);
        }

        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        public Indicator.VOLBasedColor VOLBasedColor(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.VOLBasedColor(input);
        }

    }
}
#endregion
